@@ -207,6 +207,10 @@ class Field:
         if index < 0:
             return
 
+        if self.base_type != BaseType.STRING:
+            if not self.base_type.is_valid(encoded_value):
+                raise Exception(f'Encoded value {encoded_value} is not in valid range [{self.base_type.min}, {self.base_type.max}]')
+
         size_changed = False
         while index >= self.length:
             if self.base_type != BaseType.STRING and not self.growable:
